@@ -1,14 +1,13 @@
-from typing import Annotated, Any, ClassVar, cast, Generic
+from typing import Annotated, Generic, cast
 
 from msgspec import Meta
 
 from lihil.constant import status as http_status
-from lihil.interface.struct import Record
 from lihil.interface import T
+from lihil.interface.struct import Record
 from lihil.utils.string import to_kebab_case, trimdoc
 
 
-# =========
 class ProblemDetail(Record, Generic[T]):  # user can inherit this and extend it
     """
     ## Specification:
@@ -59,9 +58,9 @@ class ProblemDetail(Record, Generic[T]):  # user can inherit this and extend it
 
 class DetailBase(Generic[T]):
     __slots__: tuple[str, ...] = ()
-    __status__: ClassVar[http_status.Status]
-    __problem_type__: ClassVar[str | None] = None
-    __problem_title__: ClassVar[str | None] = None
+    __status__: http_status.Status
+    __problem_type__: str | None = None
+    __problem_title__: str | None = None
 
     detail: T
 
@@ -69,7 +68,7 @@ class DetailBase(Generic[T]):
         raise NotImplementedError
 
     @classmethod
-    def __json_example__(cls) -> dict[str, Any]:
+    def __json_example__(cls) -> ProblemDetail[T]:
         type_ = cls.__problem_type__ or to_kebab_case(cls.__name__)
         title = cls.__problem_title__ or trimdoc(cls.__doc__) or "Missing"
         status = cls.__status__
@@ -79,4 +78,4 @@ class DetailBase(Generic[T]):
             status=status,
             detail=cast(T, "Example detail for this error type"),
             instance="Example Instance for this error type",
-        ).asdict()
+        )
