@@ -814,3 +814,14 @@ async def test_ep_with_props_encoder(rusers: Route, lc: LocalClient):
 
     ep = await lc.make_endpoint(get, encoder=dummy)
     assert ep.encoder is dummy
+
+
+async def test_param_typing(rusers: Route, lc: LocalClient):
+    async def get(q: Annotated[str, Param()]): ...
+
+    def query_decoder(content: str) -> list[int]: ...
+
+    def body_decoder(content: bytes) -> list[int]: ...
+
+    async def get(q: Annotated[str, Param(decoder=query_decoder)]): ...
+    async def get(q: Annotated[str, Param("body", decoder=body_decoder)]): ...
